==> aksharamukha-1.0.12.tar.gz: aksharamukha-1.0.12/aksharamukha/ScriptMap/MainIndic/Telugu.py <==
# -*- coding: utf-8 -*-

# Script Mapping for Devanagari

VowelMap =  [
            '\u0C05',
            '\u0C06',
            '\u0C07',
            '\u0C08',
            '\u0C09',
            '\u0C0A',
            '\u0C0B',
            '\u0C60',
            '\u0C0C',
            '\u0C61',
            '\u0C0F',
            '\u0C10',
            '\u0C13',
            '\u0C14',
            ]

SouthVowelMap = [
                '\u0C0E',
                '\u0C12',
                ]

ModernVowelMap = [
                 '\u0C0E\u02BC',
                 '\u0C06\u02BC',
                 ]

SinhalaVowelMap = [
                  '\u0C0F\u02C7'
                  ]

VowelSignMap =  [
                '\u0C3E',
                '\u0C3F',
                '\u0C40',
                '\u0C41',
                '\u0C42',
                '\u0C43',
                '\u0C44',
                '\u0C62',
                '\u0C63',
                '\u0C47',
                '\u0C48',
                '\u0C4B',
                '\u0C4C',
                ]

SouthVowelSignMap = [
                    '\u0C46',
                    '\u0C4A',
                    ]

ModernVowelSignMap =[
                    '\u0C46\u02BC',
                    '\u0C3E\u02BC']

SinhalaVowelSignMap = [
                      '\u0C47\u02C7'
                      ]

AyogavahaMap = [
               '\u0C00',
               '\u0C02',
               '\u0C03'
               ]

ViramaMap =  [
             '\u0C4D'
             ]

ConsonantMap =  [
                '\u0C15',
                '\u0C16',
                '\u0C17',
                '\u0C18',
                '\u0C19',

                '\u0C1A',
                '\u0C1B',
                '\u0C1C',
                '\u0C1D',
                '\u0C1E',

                '\u0C1F',
                '\u0C20',
                '\u0C21',
                '\u0C22',
                '\u0C23',

                '\u0C24',
                '\u0C25',
                '\u0C26',
                '\u0C27',
                '\u0C28',

                '\u0C2A',
                '\u0C2B',
                '\u0C2C',
                '\u0C2D',
                '\u0C2E',

                '\u0C2F',
                '\u0C30',
                '\u0C32',
                '\u0C35',

                '\u0C36',
                '\u0C37',
                '\u0C38',
                '\u0C39'
                ]

SouthConsonantMap = [
                    '\u0C33',
                    'ఴ',
                    '\u0C31',
                    '\u0C28\u00B7'
                    ]

NuktaConsonantMap =  [
                     '\u0C15\u00B7',
                     '\u0C16\u00B7',
                     '\u0C17\u00B7',
                     '\u0C1C\u00B7',
                     '\u0C21\u00B7',
                     '\u0C22\u00B7',
                     '\u0C2B\u00B7',
                     '\u0C2F\u00B7'
                     ]

SinhalaConsonantMap =[
                     '\u0C01\u02C6\u0C17',
                     '\u0C01\u02C6\u0C1C',
                     '\u0C01\u02C6\u0C21',
                     '\u0C01\u02C6\u0C26',
                     '\u0C01\u02C6\u0C2C',
                      ]

NuktaMap = [
           '\u00B7'
           ]

OmMap = [
        '\u0C13\u0C02'
        ]

SignMap =[
         '\u0C3D',
         '\u0964',
         '\u0965'
         ]

Aytham =[AyogavahaMap[2]+'\u02BC']


NumeralMap = [
             '\u0C66',
             '\u0C67',
             '\u0C68',
             '\u0C69',
             '\u0C6A',
             '\u0C6B',
             '\u0C6C',
             '\u0C6D',
             '\u0C6E',
             '\u0C6F'
             ]

==> aksharamukha-2.0.2.tar.gz: aksharamukha-2.0.2/aksharamukha/ScriptMap/MainIndic/Telugu.py <==
# -*- coding: utf-8 -*-

# Script Mapping for Devanagari

VowelMap =  [
            '\u0C05',
            '\u0C06',
            '\u0C07',
            '\u0C08',
            '\u0C09',
            '\u0C0A',
            '\u0C0B',
            '\u0C60',
            '\u0C0C',
            '\u0C61',
            '\u0C0F',
            '\u0C10',
            '\u0C13',
            '\u0C14',
            ]

SouthVowelMap = [
                '\u0C0E',
                '\u0C12',
                ]

ModernVowelMap = [
                 '\u0C0E\u0952\u200B',
                 '\u0C12\u0952\u200B',
                 ]

SinhalaVowelMap = [
                  '\u0C0F\u0952\u200B'
                  ]

VowelSignMap =  [
                '\u0C3E',
                '\u0C3F',
                '\u0C40',
                '\u0C41',
                '\u0C42',
                '\u0C43',
                '\u0C44',
                '\u0C62',
                '\u0C63',
                '\u0C47',
                '\u0C48',
                '\u0C4B',
                '\u0C4C',
                ]

SouthVowelSignMap = [
                    '\u0C46',
                    '\u0C4A',
                    ]

ModernVowelSignMap =[
                    '\u0C46\u0952\u200B',
                    '\u0C4A\u0952\u200B']

SinhalaVowelSignMap = [
                      '\u0C47\u0952\u200B'
                      ]

AyogavahaMap = [
               '\u0C00',
               '\u0C02',
               '\u0C03'
               ]

ViramaMap =  [
             '\u0C4D'
             ]

ConsonantMap =  [
                '\u0C15',
                '\u0C16',
                '\u0C17',
                '\u0C18',
                '\u0C19',

                '\u0C1A',
                '\u0C1B',
                '\u0C1C',
                '\u0C1D',
                '\u0C1E',

                '\u0C1F',
                '\u0C20',
                '\u0C21',
                '\u0C22',
                '\u0C23',

                '\u0C24',
                '\u0C25',
                '\u0C26',
                '\u0C27',
                '\u0C28',

                '\u0C2A',
                '\u0C2B',
                '\u0C2C',
                '\u0C2D',
                '\u0C2E',

                '\u0C2F',
                '\u0C30',
                '\u0C32',
                '\u0C35',

                '\u0C36',
                '\u0C37',
                '\u0C38',
                '\u0C39'
                ]

SouthConsonantMap = [
                    '\u0C33',
                    'ఴ',
                    '\u0C31',
                    '\u0C28\u00B7'
                    ]

NuktaConsonantMap =  [
                     '\u0C15\u00B7',
                     '\u0C16\u00B7',
                     '\u0C17\u00B7',
                     '\u0C1C\u00B7',
                     '\u0C21\u00B7',
                     '\u0C22\u00B7',
                     '\u0C2B\u00B7',
                     '\u0C2F\u00B7'
                     ]

SinhalaConsonantMap =[
                     '\u0C01\u02C6\u0C17',
                     '\u0C01\u02C6\u0C1C',
                     '\u0C01\u02C6\u0C21',
                     '\u0C01\u02C6\u0C26',
                     '\u0C01\u02C6\u0C2C',
                      ]

NuktaMap = [
           '\u00B7'
           ]

OmMap = [
        '\u0C13\u0C02'
        ]

SignMap =[
         '\u0C3D',
         '\u0964',
         '\u0965'
         ]

Aytham =[AyogavahaMap[2]+'\u02BC']


NumeralMap = [
             '\u0C66',
             '\u0C67',
             '\u0C68',
             '\u0C69',
             '\u0C6A',
             '\u0C6B',
             '\u0C6C',
             '\u0C6D',
             '\u0C6E',
             '\u0C6F'
             ]
